.. gcm-filters documentation master file, created by
   sphinx-quickstart on Tue Jan 12 09:24:23 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to intake-axds's documentation!
=======================================

Installation
------------

To install from PyPI:
  >>> pip install intake-axds

.. toctree::
   :maxdepth: 2

   demo_overview.md
   api
   GitHub repository <https://github.com/axiom-data-science/intake-axds>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _reStructuredText: https://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
